#OUTPUTS
SHEXC = "ShEx"
SHACL_TURTLE = "Shacl"

#INPUT FORMATS
NT = "nt"
TSV_SPO = "tsv_spo"
TURTLE = "turtle"
TURTLE_ITER = "turtle_iter"
RDF_XML = "xml"
N3 = "n3"
JSON_LD = "json-ld"

#SHAPE MAP FORMATS
JSON = "json"
FIXED_SHAPE_MAP = "fsm"

#FREQUENT INSTATIATION PROPERTIES
RDF_TYPE = "http://www.w3.org/1999/02/22-rdf-syntax-ns#type"
WIKIDATA_INSTACE_OF = "http://www.wikidata.org/prop/direct/P31"

#NAMESPACES
SHAPES_DEFAULT_NAMESPACE = "http://weso.es/shapes/"

#COMPRESSION FORMATS
ZIP = "zip"
GZ = "gz"

# FREQUENCY MODES

RATIO_INSTANCES = "ratio"
ABSOLUTE_INSTANCES = "abs"
MIXED_INSTANCES = "mixed"




from shexer.core.profiling.strategy.abstract_strategy import AbstractStrategy
from shexer.core.profiling.consts import _S


class DirectFeaturesStrategy(AbstractStrategy):

    def __init__(self, class_profiler):
        super().__init__(class_profiler)


    def adapt_instances_dict(self):
        for a_subj_key in self._i_dict:
            self._i_dict[a_subj_key] = \
                (self._i_dict[a_subj_key], {})

    def is_a_relevant_triple(self, a_triple):
        return self._is_relevant_instance(a_triple[_S])

    def annotate_triple_features(self, a_triple):
        self._annotate_target_subject(a_triple)

    def annotate_instance_features(self, an_instance):
        self._annotate_direct_instance_features(an_instance)

    def init_annotated_targets(self):
        self._init_annotated_direct_features()

    def init_original_targets(self):
        if self._original_raw_target_classes:
            for a_class in self._original_raw_target_classes:
                self._c_shapes_dict[a_class] = {}
                self._c_counts[a_class] = 0

    def has_shape_annotated_features(self, shape_label):
        if shape_label not in self._c_shapes_dict:
            return False
        return len(self._c_shapes_dict[shape_label]) > 0


